@@ -3,15 +3,14 @@ Base class for all collector plugins
 """
 
 import json
-
+import socket
 from abc import abstractmethod
 from pathlib import Path
-import socket
 from typing import Any, List, Optional, Union, final
 from urllib.parse import urlparse
-from packageurl import PackageURL  # type: ignore
 
 from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
+from packageurl import PackageURL  # type: ignore
 
 from hoppr import __version__, plugin_utils
 from hoppr.base_plugins.hoppr import HopprPlugin, hoppr_process, hoppr_rerunner
@@ -91,8 +90,6 @@ class BaseCollectorPlugin(HopprPlugin):
 
         parsed_purl_url = BaseCollectorPlugin._parse_url_for_comparison(purl_url)
         parsed_repo_url = BaseCollectorPlugin._parse_url_for_comparison(repo_url)
-        print(f"DEBUG: Purl: {parsed_purl_url}")
-        print(f"DEBUG: repo: {parsed_repo_url}")
         if (
             parsed_repo_url[0] == parsed_purl_url[0]
             and (not parsed_purl_url[1] or parsed_repo_url[1] == parsed_purl_url[1])
